@@ -405,7 +405,7 @@ class Deploy (Resources):
         print ('unregistering images...')
         for img in images [keep:]:
             self.remove_image (img ['ImageId'])
-            print ('- image unregistered: {}'.format (id))
+            print ('- image unregistered: {}'.format (img ['ImageId']))
 
     def get_elb_targets (self, target_group_arn = None):
         return elb2.describe_target_health (TargetGroupArn = target_group_arn or self.ELB_GROUP_ARN) ['TargetHealthDescriptions']
