@@ -8,6 +8,7 @@ class Telegram:
     def __init__ (self, token):
         self.token = token
         self.bot = telegram.Bot(token = token)
+        self.chat_id = None
 
     def show_messages (self):
         updates = self.bot.getUpdates()
@@ -18,25 +19,30 @@ class Telegram:
         return self.bot.getUpdates()
 
     def send (self, msg, chat_id = None):
+        msgs = self.updates ()
+        if msgs:
+            self.chat_id = msgs [-1].message.chat.id
+
         self.bot.sendMessage (
-            chat_id or self.updates ()[-1].message.chat.id,
+            chat_id or self.chat_id,
             msg
         )
 
 
 if __name__ == "__main__":
     import sys, os
+    import time
     from telegram.error import TimedOut
 
     token = os.environ.get ('TELEGRAM_TOKEN')
     if not token:
         raise SystemExit ('telegram token reqired')
     commit_title = os.environ.get ("CI_COMMIT_TITLE", "")
-    if commit_title.find ('--tg-slient') != -1:
+    if commit_title.find ('--tg-silent') != -1:
         sys.exit ()
 
     bot = Telegram (token)
-    for i in range (3):
+    for i in range (7):
         try:
             bot.send (' '.join (sys.argv [1:]))
         except TimedOut:
