@@ -114,6 +114,7 @@ class screen_logger (base_logger):
 	def __init__ (self, cacheline = 200, flushnow = 1, colored = True):
 		base_logger.__init__(self, sys.stdout, cacheline, flushnow)
 		self.colored = sys.stdout.isatty() and colored
+		self.hide_date = os.get ("DAEMONIZER") == 'systemd'
 
 	def close (self):
 		pass
@@ -131,7 +132,10 @@ class screen_logger (base_logger):
 			return line
 
 		if not self.colored:
-			line = "{} {}{}\n".format (now(), self.tag (type, name), line)
+			if self.hide_date:
+				line = "{}{}\n".format (self.tag (type, name), line)
+			else:
+				line = "{} {}{}\n".format (now(), self.tag (type, name), line)
 		else:
 			try:
 				type_color = getattr (tc, basetype)
